@@ -40,7 +40,7 @@
 #include "cache.h"
 #include "agent-nmapxml.h"
 
-//#define DEBUG_OS_SCAN
+#define DEBUG_OS_SCAN
 
 #ifdef DEBUG_OS_SCAN
 	#define DEBUG(a) a
