@@ -60,7 +60,7 @@ event_hdr *eh = (event_hdr *)ebuf;
 event *ee = (event *)(ebuf + sizeof(event_hdr));
 int dopasswords = FALSE;
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	int dossl = FALSE;
 #endif
 
@@ -93,7 +93,7 @@ void usage()
 	                "          -f: Fork to background\n"
 #endif
 	                "          -p: Authenticate clients with passwords\n"
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	                "          -s: Use SSL for transferring information (USE THIS WITH -p!!!)\n"
 #else
 	                "              WARNING: without openssl your passwords will be\n"
@@ -123,7 +123,7 @@ void *do_it(void *type)
 		exit(1);
 	}
 	authenticate_clients(dopasswords);
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 		use_ssl(dossl);
 #endif
 	register_agent_handlers();
@@ -167,7 +167,7 @@ int main(int argc, char *argv[])
 	                  "f"
 #endif	                  
 	                  "p"
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	                  "s"
 #endif
 	                  )) 
@@ -192,7 +192,7 @@ int main(int argc, char *argv[])
 		case 'p':
 			dopasswords++;
 			break;
-#ifdef HAS_SSL			
+#if defined(HAS_SSL) && defined(USING_SSL)			
 		case 's':
 			dossl++;
 			break;
@@ -219,7 +219,7 @@ int main(int argc, char *argv[])
 	init_osscan();
 	init_probes();
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	if(dopasswords && !dossl)
 	{
 		fprintf(stderr, "WARNING!!! using -p without -s will reveal all passwords\n"
