@@ -849,6 +849,10 @@ int main(int argc, char *argv[])
 
 	register_gui_handlers();
 
+#ifdef USING_MONITORING	
+	gui_monitoring_init();
+#endif
+
 	if( (main_window = NEW(cheops_window)) == NULL)
 	{
 		quit();
