@@ -26,11 +26,15 @@
 
 #include <gnome.h>
 #include <glib.h>
+#include "config.h"
+#include "cheops-config.h"
 #include "event.h"
 #include "gui-handlers.h"
 #include "gui-pixmap.h"
 #include "version.h"
-
+#ifdef USING_MONITORING
+	#include "gui-monitoring.h"
+#endif
 #define CHEOPS_DEFAULT_FILENAME_NOT_HOME ".gnome/cheops-ng.map"
 #define CHEOPS_DEFAULT_FILENAME "~/.gnome/cheops-ng.map"
 #define CHEOPS_TITLE "cheops-ng"
@@ -113,6 +117,10 @@ typedef struct _page_object {
 	os_stats            *os_data;
 	
 	GtkWidget           *info_window;
+#ifdef USING_MONITORING
+	GtkWidget           *monitoring_vbox;   // the container to put all of the stuff into
+	GtkWidget           *monitoring_hbox;   // parent of the vbox
+#endif
 } page_object;
 
 /* defines for the flags member in the page_object */
@@ -123,6 +131,7 @@ typedef struct _page_object {
 #define PAGE_OBJECT_CONFIG_NEW	 		0x00000010
 #define PAGE_OBJECT_OS_DETECT_SENT		0x00000020
 
+#define PAGE_OBJECT(a) ((page_object *)a)
 
 /*
  * Each page in the cheops_window is a net_page
