@@ -46,7 +46,7 @@
 #include <pthread.h>
 #include "logger.h"
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	#include <openssl/ssl.h>
 	#include <openssl/err.h>
 	#include <openssl/rand.h>
@@ -102,7 +102,7 @@ static agent *agents=NULL;
 
 int authenticate_connecting_clients = 0;
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	int initalized_ssl = 0;
 	int connect_with_ssl = 0;
 	SSL_CTX *ssl_ctx;
@@ -149,7 +149,7 @@ int authenticating_clients(void)
 	return(authenticate_connecting_clients);
 }
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 void agent_use_ssl(agent *a, int enable)
 {
 	if(enable)
@@ -589,7 +589,7 @@ static int handle_ipv4_connect(int *id, int fd, short events, void *data)
 			a->more = &ipv4_connect_string[0];
 			a->flags = 0;
 			
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 			if( using_ssl() ) {
 				int ret;
 				
@@ -691,7 +691,7 @@ static agent *ipv4_agent(char *ip_addr, int usessl, int is_client)
 			a->s = s;
 			a->more = &ipv4_string[0];
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 			if( usessl ) 
 			{
 				if(!initalized_ssl) 
@@ -729,7 +729,7 @@ static agent *ipv4_agent(char *ip_addr, int usessl, int is_client)
 	}
 	if(!is_client)
 		our_local_ipv4_agent = a;
-#ifdef HAS_SSL	
+#if defined(HAS_SSL) && defined(USING_SSL)	
 	agent_use_ssl(a, usessl);
 #endif
 	return a;
