@@ -40,7 +40,9 @@
 #include "gui-pixmap.h"
 #include "gui-handlers.h"
 #include "gui-dns.h"
-
+#ifdef USING_MONITORING
+	#include "gui-monitoring.h"
+#endif
 //#define DEBUG_CANVAS
 
 #ifdef DEBUG_CANVAS
@@ -1806,13 +1808,26 @@ void page_object_show_properties(GtkWidget *w, gpointer data)
  *************************************/
  
 		label = gtk_label_new("Monitoring");
+		hbox = gtk_vbox_new(FALSE, 5);
+		gtk_widget_show(hbox);
+		gtk_notebook_append_page(GTK_NOTEBOOK(main_notebook),hbox, label); 
+
 		vbox = gtk_vbox_new(FALSE, 5);
 		gtk_widget_show(vbox);
-		gtk_notebook_append_page(GTK_NOTEBOOK(main_notebook),vbox, label); 
-		
+		gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 5);
+
+#ifdef USING_MONITORING		
+		label = gtk_label_new("Monitoring");
+		gtk_widget_show(label);
+		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 5);
+		po->monitoring_vbox = vbox;
+		po->monitoring_hbox = hbox;
+		gui_monitoring_toplevel(po);
+#else /* USING_MONITORING */
 		label = gtk_label_new("Not Working Yet");
 		gtk_widget_show(label);
 		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 5);
+#endif /* USING_MONITORING */
 /*************************************
  *     comments
  *************************************/
@@ -1984,6 +1999,22 @@ void dns_option_callback(net_page *np, page_object *po, GtkWidget *menu, void *d
 	gtk_widget_show(item);
 }
 
+#ifdef USING_MONITORING
+void monitoring_option_callback(net_page *np, page_object *po, GtkWidget *menu, void *data)
+{
+	GtkWidget *item;
+	char *name = "Monitoring";
+	
+	item = gtk_menu_item_new_with_label(name);
+	gtk_signal_connect(GTK_OBJECT(item), "activate",
+	                   GTK_SIGNAL_FUNC(gui_monitoring_make_dialog),
+	                   (gpointer)po);
+	
+	gtk_menu_append(GTK_MENU(menu), item);
+	gtk_widget_show(item);
+}
+#endif /* USING_MONITORING */
+
 void merge_option_set_merge_primary(GtkWidget *w, gpointer data)
 {
 	page_object *po = (page_object *)data;
@@ -2295,9 +2326,18 @@ void init_net_page_stuff(void)
 	page_object_option_list_add("dns",
 	                            (page_object_list_callback)dns_option_callback, 
 	                            NULL);
-	page_object_option_list_add("seperator", 
+	page_object_option_list_add("seperator2", 
 	                            (page_object_list_callback)seperator_option_callback, 
 	                            NULL);
+#ifdef USING_MONITORING
+	page_object_option_list_add("monitoring",
+	                            (page_object_list_callback)monitoring_option_callback, 
+	                            NULL);
+	page_object_option_list_add("seperator3", 
+	                            (page_object_list_callback)seperator_option_callback, 
+	                            NULL);
+#endif /* USING_MONITORING */
+
 	page_object_option_list_add("delete", 
 	                            (page_object_list_callback)delete_option_callback, 
 	                            NULL);
