@@ -404,6 +404,7 @@ service_list_t *services_make_dialog(service_list_t *service, char *name, int po
 	comboList = g_list_append(comboList, "TCP");
 	comboList = g_list_append(comboList, "UDP");
 	gtk_combo_set_popdown_strings(GTK_COMBO(protocol_w),comboList);
+	g_list_free(comboList);
 	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(protocol_w)->entry), FALSE);
 
 	
@@ -570,7 +571,7 @@ void probe_ports_unselect_row(GtkWidget *clist, gint row, gint column, GdkEventB
 {
 	probe_ports_row_number = -1;
 }
-#ifdef NOT_YET
+#ifdef USING_PROBE_PORTS
 
 service_list_t *probe_ports_make_dialog(service_list_t *service, char *name, int port, int protocol, char *str, GtkWidget *parent)
 {
@@ -583,7 +584,7 @@ service_list_t *probe_ports_make_dialog(service_list_t *service, char *name, int
 	GtkWidget *label;
 	char *ptrs[4];
 	char buf[256];
-	service_list_t *srv;
+	service_list_t *srv = NULL;
 	GList *comboList = NULL;
 	
 	dialog = gnome_dialog_new("Add a Service Entry",
@@ -601,6 +602,7 @@ service_list_t *probe_ports_make_dialog(service_list_t *service, char *name, int
 	comboList = g_list_append(comboList, "TCP");
 	comboList = g_list_append(comboList, "UDP");
 	gtk_combo_set_popdown_strings(GTK_COMBO(protocol_w),comboList);
+	g_list_free(comboList);
 	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(protocol_w)->entry), FALSE);
 
 	
@@ -686,14 +688,12 @@ service_list_t *probe_ports_make_dialog(service_list_t *service, char *name, int
 	return(service);
 
 }
-#endif
 
 void probe_ports_do_add(GtkWidget *w, GtkWidget *parent)
 {
-#ifdef NOT_YET	
 	char *ptrs[4];
 	char buf[256];
-	srv = probe_ports_make_dialog(NULL, NULL,-1, 6, NULL, parent);
+	service_list_t *srv = probe_ports_make_dialog(NULL, NULL,-1, 6, NULL, parent);
 	if(srv)
 	{
 		sprintf(buf, "%d", srv->port);
@@ -709,12 +709,10 @@ void probe_ports_do_add(GtkWidget *w, GtkWidget *parent)
 		
 		gtk_clist_thaw(GTK_CLIST(probe_ports_clist));
 	}
-#endif
 }
 
 void probe_ports_do_configure(GtkWidget *w, GtkWidget *parent)
 {
-#ifdef NOT_YET
 	int num = probe_ports_row_number;
 	char buf[256];
 	service_list_t *service;
@@ -741,12 +739,10 @@ void probe_ports_do_configure(GtkWidget *w, GtkWidget *parent)
 		gtk_clist_set_row_data(GTK_CLIST(probe_ports_clist), num, service);
 	}		
 	gtk_clist_thaw(GTK_CLIST(probe_ports_clist));
-#endif
 }
 
 void probe_ports_do_delete(GtkWidget *w, gpointer p)
 {
-#ifdef NOT_YET
 	service_list_t *service;
 	
 	if(probe_ports_row_number < 0)
@@ -760,8 +756,8 @@ void probe_ports_do_delete(GtkWidget *w, gpointer p)
 	gtk_clist_thaw(GTK_CLIST(probe_ports_clist));
 
 	probe_ports_row_number = -1;
-#endif
 }
+#endif /* USING_PROBE_PORTS */
 
 /*************************************************************************
  *             os pixmap functions  
@@ -1036,7 +1032,7 @@ void do_settings(GtkWidget *widget, gpointer data)
 	char *os_pixmaps_clist_titles[] = {"File Name", "Familiar string for OS" };
     GtkWidget *os_pixmaps_delete;
     GtkWidget *os_pixmaps_edit;
-#ifdef NOT_YET
+#ifdef USING_PROBE_PORTS
 	char *plugins_clist_titles[] = {"Plugin Name", "Description"};
 	char *probe_ports_clist_titles[] = {"Service Name", "Port", "Send data", "Recieve Parser", "Recieve Parser Argument"};
 #endif	
@@ -1078,6 +1074,7 @@ void do_settings(GtkWidget *widget, gpointer data)
 		char_ptr += strlen(char_ptr) + 1;
 	}
 	gtk_combo_set_popdown_strings(GTK_COMBO(discover_retries),comboList);
+	g_list_free(comboList);
 	gtk_combo_set_use_arrows_always(GTK_COMBO(discover_retries),1);
 	sprintf(comboListBuffer, "%d", options_discover_retries);
 	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(discover_retries)->entry), comboListBuffer);
@@ -1138,6 +1135,7 @@ void do_settings(GtkWidget *widget, gpointer data)
 	comboList = g_list_append(comboList, TCP_SCAN_3);
 	comboList = g_list_append(comboList, TCP_SCAN_4);
 	gtk_combo_set_popdown_strings(GTK_COMBO(os_scan_tcp_scan),comboList);
+	g_list_free(comboList);
 	gtk_combo_set_use_arrows_always(GTK_COMBO(os_scan_tcp_scan),1);
 	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(os_scan_tcp_scan)->entry), options_os_scan_tcp_scan);
 	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(os_scan_tcp_scan)->entry), FALSE);
@@ -1158,6 +1156,7 @@ void do_settings(GtkWidget *widget, gpointer data)
 	comboList = g_list_append(comboList, TIMING_SCAN_AGGRESSIVE);
 	comboList = g_list_append(comboList, TIMING_SCAN_INSANE);
 	gtk_combo_set_popdown_strings(GTK_COMBO(os_scan_timing),comboList);
+	g_list_free(comboList);
 	gtk_combo_set_use_arrows_always(GTK_COMBO(os_scan_timing),1);
 	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(os_scan_timing)->entry), options_os_scan_timing);
 	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(os_scan_timing)->entry), FALSE);
@@ -1358,7 +1357,7 @@ void do_settings(GtkWidget *widget, gpointer data)
 /*
  * Service Version Detection Tab
  */
-#ifdef NOT_YET
+#ifdef USING_PROBE_PORTS
 	label = gtk_label_new("Service Version Detection");
 	table2 = gtk_table_new(6, 3, TRUE);
 
@@ -1492,7 +1491,7 @@ void do_settings(GtkWidget *widget, gpointer data)
 	gtk_widget_show(scrolled_window);
 	gtk_widget_show(table2);
 
-#ifdef NOT_YET
+#ifdef USING_PLUGINS
 /*
  * Plugins Settings Tab
  */
@@ -1517,29 +1516,28 @@ void do_settings(GtkWidget *widget, gpointer data)
 
 	gtk_container_add(GTK_CONTAINER(scrolled_window), plugins_clist);
 
-	gtk_table_attach_defaults(GTK_TABLE(table2), scrolled_window, 0, 3, 0, 5);
+	gtk_table_attach_defaults(GTK_TABLE(table2), scrolled_window, 0, 3, 0, 8);
 	
 	button = gnome_pixmap_button( gnome_stock_pixmap_widget(dialog, GNOME_STOCK_PIXMAP_ADD), "Add");
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(plugins_do_add), dialog);
-	gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 5, 6, GTK_FILL, GTK_FILL, 5, 5);
+	gtk_table_attach(GTK_TABLE(table2), button, 0, 1, 8, 9, GTK_FILL, GTK_FILL, 5, 5);
 	gtk_widget_show(button);
 
 	button = gnome_pixmap_button( gnome_stock_pixmap_widget(dialog, GNOME_STOCK_PIXMAP_PROPERTIES), "Configure");
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(plugins_do_configure), dialog);
-	gtk_table_attach(GTK_TABLE(table2), button, 1, 2, 5, 6, GTK_FILL, GTK_FILL, 5, 5);
+	gtk_table_attach(GTK_TABLE(table2), button, 1, 2, 8, 9, GTK_FILL, GTK_FILL, 5, 5);
 	gtk_widget_show(button);
 
 	button = gnome_pixmap_button( gnome_stock_pixmap_widget(dialog, GNOME_STOCK_PIXMAP_REMOVE), "Remove");
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(plugins_do_delete), NULL);
-	gtk_table_attach(GTK_TABLE(table2), button, 2, 3, 5, 6, GTK_FILL, GTK_FILL, 5, 5);
+	gtk_table_attach(GTK_TABLE(table2), button, 2, 3, 8, 9, GTK_FILL, GTK_FILL, 5, 5);
 	gtk_widget_show(button);
 	
 	
 	gtk_widget_show(scrolled_window);
 	gtk_widget_show(plugins_clist);
 	gtk_widget_show(table2);
-#endif /* NOT_YET */
-
+#endif
 /* this is the end of the notebook */
 
 	gtk_widget_show(notebook);
