@@ -195,7 +195,7 @@ net_page *make_viewspace(char *c, char *agent_ip, int usessl)
 {
 	net_page *np, *npp, *prev;
 	char *buf;
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 	GtkWidget *checkbox;
 #endif
 	GtkWidget *dialog;
@@ -310,7 +310,7 @@ net_page *make_viewspace(char *c, char *agent_ip, int usessl)
 		gtk_box_pack_start( GTK_BOX(hbox), entry1, FALSE, FALSE, 5);
 		gtk_box_pack_start( GTK_BOX( GNOME_DIALOG(dialog)->vbox ), hbox, TRUE, TRUE, 0);
 
-#ifdef HAS_SSL
+#if defined(HAS_SSL) && defined(USING_SSL)
 		checkbox = gtk_check_button_new_with_label("Use SSL");
 		gtk_signal_connect(GTK_OBJECT(checkbox), "toggled", toggle_dialog_toggle, &usessl);
 		gtk_box_pack_start( GTK_BOX( GNOME_DIALOG(dialog)->vbox ), checkbox, TRUE, TRUE, 0);
